==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/LastOperationBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LastOperationBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.LastOperationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.LastOperation,io.fabric8.openshift.api.model.machine.v1beta1.LastOperationBuilder>{
  public LastOperationBuilder() {
    this(false);
  }
  public LastOperationBuilder(java.lang.Boolean validationEnabled) {
    this(new LastOperation(), validationEnabled);
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<?> fluent) {
    this(fluent, false);
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LastOperation(), validationEnabled);
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance) {
    this(fluent, instance, false);
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withState(instance.getState()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance) {
    this(instance,false);
  }
  public LastOperationBuilder(io.fabric8.openshift.api.model.machine.v1beta1.LastOperation instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withState(instance.getState()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.LastOperationFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.LastOperation build() {
    LastOperation buildable = new LastOperation(fluent.getDescription(),fluent.getLastUpdated(),fluent.getState(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LastOperationBuilder that = (LastOperationBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.5.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/LastOperationBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LastOperationBuilder extends LastOperationFluentImpl<LastOperationBuilder> implements VisitableBuilder<LastOperation,LastOperationBuilder>{
  public LastOperationBuilder() {
    this(false);
  }
  public LastOperationBuilder(Boolean validationEnabled) {
    this(new LastOperation(), validationEnabled);
  }
  public LastOperationBuilder(LastOperationFluent<?> fluent) {
    this(fluent, false);
  }
  public LastOperationBuilder(LastOperationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LastOperation(), validationEnabled);
  }
  public LastOperationBuilder(LastOperationFluent<?> fluent,LastOperation instance) {
    this(fluent, instance, false);
  }
  public LastOperationBuilder(LastOperationFluent<?> fluent,LastOperation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withState(instance.getState()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LastOperationBuilder(LastOperation instance) {
    this(instance,false);
  }
  public LastOperationBuilder(LastOperation instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withState(instance.getState()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  LastOperationFluent<?> fluent;
  Boolean validationEnabled;
  public LastOperation build() {
    LastOperation buildable = new LastOperation(fluent.getDescription(),fluent.getLastUpdated(),fluent.getState(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
